From dd48b295d1e19e3d25fca96bfad820d007b137a1 Mon Sep 17 00:00:00 2001
From: "ericroman@google.com"
 <ericroman@google.com@0039d316-1c4b-4281-b951-d872f2087c98>
Date: Wed, 15 Oct 2008 20:57:46 +0000
Subject: Make new http stack the default for test_shell.exe. The consequence
 of this change is the buildbots will be running layout tests with the new
 stack.

Review URL: http://codereview.chromium.org/7409

git-svn-id: svn://svn.chromium.org/chrome/trunk/src@3415 0039d316-1c4b-4281-b951-d872f2087c98
---
 webkit/tools/layout_tests/test_lists/tests_fixable.txt | 8 ++++++++
 webkit/tools/test_shell/test_shell_main.cc             | 5 ++---
 webkit/tools/test_shell/test_shell_switches.cc         | 4 ++--
 webkit/tools/test_shell/test_shell_switches.h          | 2 +-
 4 files changed, 13 insertions(+), 6 deletions(-)

(limited to 'webkit/tools')

diff --git a/webkit/tools/layout_tests/test_lists/tests_fixable.txt b/webkit/tools/layout_tests/test_lists/tests_fixable.txt
index b87fe06..939c611 100644
--- a/webkit/tools/layout_tests/test_lists/tests_fixable.txt
+++ b/webkit/tools/layout_tests/test_lists/tests_fixable.txt
@@ -22,6 +22,14 @@ V8 | KJS # LayoutTests/editing/execCommand/copy-without-selection.html = FAIL |
 // (rdar://5313536)
 V8 | KJS # LayoutTests/fast/dom/frame-loading-via-document-write.html = FAIL | TIMEOUT
 
+// Times out when using new http stack because of unsupported username:pass
+// in URL. http://code.google.com/p/chromium/issues/detail?id=3436
+V8 | KJS # SKIP : LayoutTests/http/tests/xmlhttprequest/basic-auth.html = TIMEOUT | PASS
+
+// Times out when using new http stack duplicate Cache-Control request headers
+// are sent on reload. http://code.google.com/p/chromium/issues/detail?id=3434
+V8 | KJS # SKIP : LayoutTests/http/tests/misc/refresh-headers.php = TIMEOUT | PASS
+
 // -----------------------------------------------------------------
 // FLAKY TESTS
 // -----------------------------------------------------------------
diff --git a/webkit/tools/test_shell/test_shell_main.cc b/webkit/tools/test_shell/test_shell_main.cc
index 6738984..b184dc8 100644
--- a/webkit/tools/test_shell/test_shell_main.cc
+++ b/webkit/tools/test_shell/test_shell_main.cc
@@ -152,9 +152,8 @@ int main(int argc, char* argv[]) {
 #if defined(OS_WIN)
   // Make the selection of network stacks early on before any consumers try to
   // issue HTTP requests.
-  net::HttpNetworkLayer::UseWinHttp(true);
-  if (parsed_command_line.HasSwitch(test_shell::kUseNewHttp))
-    net::HttpNetworkLayer::UseWinHttp(false);
+  if (parsed_command_line.HasSwitch(test_shell::kUseWinHttp))
+    net::HttpNetworkLayer::UseWinHttp(true);
 #endif
 
   net::HttpCache::Mode cache_mode = net::HttpCache::NORMAL;
diff --git a/webkit/tools/test_shell/test_shell_switches.h b/webkit/tools/test_shell/test_shell_switches.h
index cdda8a6..f368996 100644
--- a/webkit/tools/test_shell/test_shell_switches.h
+++ b/webkit/tools/test_shell/test_shell_switches.h
@@ -24,7 +24,7 @@ extern const wchar_t kDumpStatsTable[];
 extern const wchar_t kCacheDir[];
 extern const wchar_t kDebugMemoryInUse[];
 extern const wchar_t kEnableFileCookies[];
-extern const wchar_t kUseNewHttp[];
+extern const wchar_t kUseWinHttp[];
 extern const wchar_t kEnableTracing[];
 extern const wchar_t kAllowScriptsToCloseWindows[];
 
diff --git a/webkit/tools/test_shell/test_shell_switches.cc b/webkit/tools/test_shell/test_shell_switches.cc
index 1f21aa0..5b9bb5f 100644
--- a/webkit/tools/test_shell/test_shell_switches.cc
+++ b/webkit/tools/test_shell/test_shell_switches.cc
@@ -48,8 +48,8 @@ const wchar_t kDebugMemoryInUse[] = L"debug-memory-in-use";
 // Enable cookies on the file:// scheme.  --layout-tests also enables this.
 const wchar_t kEnableFileCookies[] = L"enable-file-cookies";
 
-// Enable new HTTP stack.
-const wchar_t kUseNewHttp[] = L"new-http";
+// Enable the winhttp network stack.
+const wchar_t kUseWinHttp[] = L"winhttp";
 
 // Enable tracing events (see base/trace_event.h)
 const wchar_t kEnableTracing[] = L"enable-tracing";
-- 
cgit v1.1